@@ -5,11 +5,12 @@ but not in subsequent imports from other modules.
 Replacing the whole time module by this one does work.
 """
 
-from time import *
+from time import *  # noqa
 from time import time as original_time
 
 from datetime import datetime
 
+
 def time():
     if datetime._current_now is None:
         return original_time()
